==> cmake_2.2.3.orig.tar.gz: cmake-2.2.3/Source/cmCommandArgumentParserTokens.h <==
/* A Bison parser, made by GNU Bison 1.875d.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     cal_NCURLY = 258,
     cal_DCURLY = 259,
     cal_DOLLAR = 260,
     cal_LCURLY = 261,
     cal_RCURLY = 262,
     cal_NAME = 263,
     cal_BSLASH = 264,
     cal_SYMBOL = 265,
     cal_AT = 266,
     cal_ERROR = 267,
     cal_ATNAME = 268
   };
#endif
#define cal_NCURLY 258
#define cal_DCURLY 259
#define cal_DOLLAR 260
#define cal_LCURLY 261
#define cal_RCURLY 262
#define cal_NAME 263
#define cal_BSLASH 264
#define cal_SYMBOL 265
#define cal_AT 266
#define cal_ERROR 267
#define cal_ATNAME 268




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif

==> cmake_2.4.3.orig.tar.gz: cmake-2.4.3/Source/cmCommandArgumentParserTokens.h <==
/* A Bison parser, made by GNU Bison 2.1.  */

/* Skeleton parser for Yacc-like parsing with Bison, Copyright (C) 1984,
   1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation,
   Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     cal_NCURLY = 258,
     cal_DCURLY = 259,
     cal_DOLLAR = 260,
     cal_LCURLY = 261,
     cal_RCURLY = 262,
     cal_NAME = 263,
     cal_BSLASH = 264,
     cal_SYMBOL = 265,
     cal_AT = 266,
     cal_ERROR = 267,
     cal_ATNAME = 268
   };
#endif
/* Tokens.  */
#define cal_NCURLY 258
#define cal_DCURLY 259
#define cal_DOLLAR 260
#define cal_LCURLY 261
#define cal_RCURLY 262
#define cal_NAME 263
#define cal_BSLASH 264
#define cal_SYMBOL 265
#define cal_AT 266
#define cal_ERROR 267
#define cal_ATNAME 268




#if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
typedef int YYSTYPE;
# define yystype YYSTYPE /* obsolescent; will be withdrawn */
# define YYSTYPE_IS_DECLARED 1
# define YYSTYPE_IS_TRIVIAL 1
#endif
